Package: BiocStyle
Title: Standard styles for vignettes and other Bioconductor documents
Description: Provides standard formatting styles for Bioconductor PDF
    and HTML documents. Package vignettes illustrate use and
    functionality.
Version: 2.40.0
Authors@R: c(
        person("Andrzej", "Oleś", role = "aut",
            comment = c(ORCID = "0000-0003-0285-2787")
        ), 
        person("Mike", "Smith", role = "ctb",
            comment = c(ORCID = "0000-0002-7800-3848")
        ),
        person("Martin", "Morgan", role = "ctb"),
        person("Wolfgang", "Huber", role = "ctb"),
        person("Bioconductor Package Maintainer", role = "cre",
            email = "maintainer@bioconductor.org")
        )
Imports: bookdown, knitr (>= 1.30), rmarkdown (>= 1.2), stats, utils,
        yaml, BiocManager
Suggests: BiocGenerics, RUnit, htmltools
biocViews: Software
License: Artistic-2.0
VignetteBuilder: knitr
Encoding: UTF-8
URL: https://github.com/Bioconductor/BiocStyle
BugReports: https://github.com/Bioconductor/BiocStyle/issues
RoxygenNote: 6.1.0
Date: 2025-08-01
git_url: https://git.bioconductor.org/packages/BiocStyle
git_branch: RELEASE_3_23
git_last_commit: 2817006
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 20:53:47 UTC; biocbuild
Author: Andrzej Oleś [aut] (ORCID: <https://orcid.org/0000-0003-0285-2787>),
  Mike Smith [ctb] (ORCID: <https://orcid.org/0000-0002-7800-3848>),
  Martin Morgan [ctb],
  Wolfgang Huber [ctb],
  Bioconductor Package Maintainer [cre]
Maintainer: Bioconductor Package Maintainer <maintainer@bioconductor.org>
