# Generated by roxygen2: do not edit by hand

export(Biocannopkg)
export(Biocbook)
export(Biocexptpkg)
export(Biocpkg)
export(CRANpkg)
export(Githubpkg)
export(Rpackage)
export(doc_date)
export(html_document)
export(latex)
export(markdown)
export(md_document)
export(output)
export(pdf_document)
export(pkg_ver)
export(use_vignette_html)
export(use_vignette_pdf)
importFrom(BiocManager,version)
importFrom(knitr,current_input)
importFrom(knitr,hook_pdfcrop)
importFrom(knitr,hook_plot_md)
importFrom(knitr,hook_plot_tex)
importFrom(knitr,knit_hooks)
importFrom(knitr,knit_theme)
importFrom(knitr,opts_chunk)
importFrom(knitr,opts_hooks)
importFrom(knitr,opts_knit)
importFrom(knitr,set_header)
importFrom(rmarkdown,draft)
importFrom(rmarkdown,knitr_options)
importFrom(rmarkdown,metadata)
importFrom(rmarkdown,output_format)
importFrom(rmarkdown,pandoc_available)
importFrom(rmarkdown,pandoc_version)
importFrom(stats,setNames)
importFrom(utils,packageVersion)
importFrom(yaml,yaml.load)
