#' Defunct functions in package \sQuote{BiocStyle}
#'
#' These functions are defunct and no longer available.
#'
#' The following functions are no longer available; use the replacement
#' indicated below:
#' \itemize{
#'   \item \code{latex_old, latex2: \link{latex}}
#'   \item \code{pdf_document_old, pdf_document2: \link{pdf_document}}
#'   \item \code{html_document_old, html_document2: \link{html_document}}
#' }
#'
#' @name BiocStyle-defunct
NULL
